//-----------------------------------------------------------------------------
// from File: GetDXVer.cpp
//
// Desc: check if DirectX 8 installed
//       is installed.
//
// (C) Copyright 1995-2000 Microsoft Corp.  All rights reserved.
//-----------------------------------------------------------------------------
{ #include <windows.h>
  #include <windowsx.h>
  #include <basetsd.h>
  #include <ddraw.h>
  #include <dinput.h>
  #include <dmusici.h>
  }

unit DXUtil;

interface

uses Windows, SysUtils, Direct3D8, D3DX8;

function GetDXVersion : DWord;

implementation

//-----------------------------------------------------------------------------
// Name: GetDXVersion()
// Desc: This function returns the DirectX version number as follows:
//          0x0000 = No DirectX installed
//          0x0700 = At least DirectX 7 installed.
//          0x0800 = At least DirectX 8 installed.
//
//       Please note that this code is intended as a general guideline. Your
//       app will probably be able to simply query for functionality (via
//       QueryInterface) for one or two components.
//
//       Please also note:
//          "if( dwDXVersion != 0x500 ) return FALSE;" is VERY BAD.
//          "if( dwDXVersion <  0x500 ) return FALSE;" is MUCH BETTER.
//       to ensure your app will run on future releases of DirectX.
//-----------------------------------------------------------------------------
function GetDXVersion : DWord;
var
  hD3D8DLL    : LongWord;
begin
    Result:= 0;
    hD3D8DLL:=0;

    //-------------------------------------------------------------------------
    // DirectX 8.0 Checks
    //-------------------------------------------------------------------------

    // Simply see if D3D8.dll exists.
    hD3D8DLL:= LoadLibrary( 'D3D8.DLL' );
    if( hD3D8DLL = 0 ) then exit;

    // D3D8.dll exists. We must be at least DX8.0
    Result:= $800;

    //-------------------------------------------------------------------------
    // End of checking for versions of DirectX
    //-------------------------------------------------------------------------

    // Close open libraries and return
    FreeLibrary( hD3D8DLL );

    end;

end.
